Range-v3: range/v3/algorithm/replace_if.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
replace_if.hpp File Reference

## Classes
struct | ranges::v3::replace_if_fn

## Typedefs
template<typename I , typename C , typename T , typename P = ident>
using | ranges::v3::ReplaceIfable = meta::strict_and< InputIterator< I >, IndirectPredicate< C, projected< I, P > >, Writable< I, T const & > >

## Variables
constexpr with_braced_init_args< replace_if_fn > | ranges::v3::replace_if {}